==> haskell-tasty-quickcheck-0.10.3-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.10.3
visibility:           public
id:                   tasty-quickcheck-0.10.3-6fiwxvJpeyvGtw4bx3c5fm
key:                  tasty-quickcheck-0.10.3-6fiwxvJpeyvGtw4bx3c5fm
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  88a5f509b59b659dad5e895fc73cc323
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.10.3-6fiwxvJpeyvGtw4bx3c5fm
depends:
    QuickCheck-2.14.3-3S3WOBL6rHa3L0CMYI1WVh base-4.17.2.1
    optparse-applicative-0.18.1.0-5z7uKq3kDhiFdyVMsq5grp
    random-1.2.1.3-1e4k6oKN9kc4OrDtxhM2uQ
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-FRQtZsdenVIBoQGCChJ79f

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10.3-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.10.3
visibility:           public
id:                   tasty-quickcheck-0.10.3-52g2dj4n8IfE3tfSyYl8uL
key:                  tasty-quickcheck-0.10.3-52g2dj4n8IfE3tfSyYl8uL
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  da3dfcb0a31125244ef3a8197f7ade13
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.10.3-52g2dj4n8IfE3tfSyYl8uL
depends:
    QuickCheck-2.14.3-FFJcwBneLUJ2oV3g9w1Xpr base-4.17.2.1
    optparse-applicative-0.18.1.0-85sZBhM4eUl6d02DyBEA2t
    random-1.2.1.3-4qsyrxcHgJtHIq1RwsIwfO
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-JCXGpGNNXiq7c99nKvAsG3

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
